@@ -1,10 +1,11 @@
 import os
+from typing import List
 
 import requests
 
 from maitai._config_listener_thread import ConfigListenerThread
-from maitai_common.version import version
 from maitai_common.config import config_service
+from maitai_common.version import version
 from maitai_gen.application import Application
 from maitai_gen.chat import ChatCompletionAuth
 from maitai_gen.config import Config as ActionConfig
@@ -86,6 +87,9 @@ class Config:
             print(f"Failed to initialize API client. Status code: {response.status_code}. Error: {response.text}")
             return
         applications = [Application().from_dict(app_json) for app_json in response.json()]
+        return self.store_application_metadata(applications)
+
+    def store_application_metadata(self, applications: List[Application]):
         for application in applications:
             self._applications[application.application_ref_name] = application
             for action_type in application.action_types:
