@@ -26,6 +26,8 @@ class MaitaiOpenAIClient:
         *,
         maitai_api_key: Optional[str] = None,
         api_key: Optional[str] = None,
+        openai_api_key: Optional[str] = None,
+        groq_api_key: Optional[str] = None,
         organization: Optional[str] = None,
         project: Optional[str] = None,
         base_url: Union[str, httpx.URL, None] = None,
@@ -36,10 +38,14 @@ class MaitaiOpenAIClient:
         http_client: Optional[httpx.Client] = None,
         _strict_response_validation: bool = False,
     ):
+        if api_key:
+            raise ValueError("The api_key parameter is not supported by Maitai. Provide openai_api_key or groq_api_key instead")
         if maitai_api_key:
             config.initialize(maitai_api_key)
-        if api_key:
-            config.auth_info.override_api_key = api_key
+        if openai_api_key:
+            config.auth_info.openai_api_key = openai_api_key
+        if groq_api_key:
+            config.auth_info.groq_api_key = groq_api_key
         self.client = openai.OpenAI(
             api_key=api_key,
             organization=organization,
@@ -135,6 +141,10 @@ class Completions:
             max_tokens = maitai_config.max_tokens
         if n == openai.NOT_GIVEN:
             n = maitai_config.n
+        if frequency_penalty == openai.NOT_GIVEN:
+            frequency_penalty = maitai_config.frequency_penalty
+        if presence_penalty == openai.NOT_GIVEN:
+            presence_penalty = maitai_config.presence_penalty
         completion_params = get_chat_completion_params(
             messages=messages,
             model=model,
